==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acuelh dau sit',
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aquel autor',
'articles_populaires' => 'Lu articles mai populars',
'articles_rubrique' => 'Articles d\'aquela rubrica',
'aucun_article' => 'I a minga d\'article a aquela adrei&ccedil;a ',
'aucun_auteur' => 'I a minga d\'autor a aquela adrei&ccedil;a ',
'aucun_site' => 'I a minga de sit a aquela adrei&ccedil;a ',
'aucune_breve' => 'I a minga de br&egrave;va a aquela adrei&ccedil;a ',
'aucune_rubrique' => 'I a minga de rubrica a aquela adrei&ccedil;a ',
'autres_breves' => 'Autri br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
'autres_sites' => 'Autres sits',

// B
'bonjour' => 'B&ograve;njorn',
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aqueu sit',

// D
'date' => 'Data',
'dernier_ajout' => 'Darrier apondon',
'dernieres_breves' => 'Darrieri br&egrave;vas',
'derniers_articles' => 'Darriers articles',
'derniers_commentaires' => 'Darriers comentaris',
'derniers_messages_forum' => 'Darriers messatges publicats dins lu forums',

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En resp&ograve;sta a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// M
'meme_auteur' => 'Dau meteis autor',
'meme_rubrique' => 'Dins la meteissa rubrica',
'memes_auteurs' => 'Dei meteis autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Lu messatges de forums mai recents',
'mots_clefs' => 'Mots clau',
'mots_clefs_meme_groupe' => 'Mots clau dins lo meteis grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Li novetats',
'nouveautes_web' => 'Novetats sobre lo web',
'nouveaux_articles' => 'Articles n&ograve;us',
'nouvelles_breves' => 'Br&egrave;vas n&ograve;vi',

// P
'page_precedente' => 'p&agrave;gina precedenta',
'page_suivante' => 'p&agrave;gina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Pod&egrave;tz participar a la vida d\'aqueu sit e prepauar lu articles v&ograve;stres en v\'inscrivent &ccedil;ai sota. Recebretz sus lo c&ograve;up un e-mail que v\'indicar&agrave; lu v&ograve;stres c&ograve;des per accedir a l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Pod&egrave;tz prepauar un sit d\'apondre a aquesta rubrica:',

// R
'repondre_article' => 'Resp&ograve;ndre a aquel article',
'repondre_breve' => 'Resp&ograve;ndre a aquela br&egrave;va',
'repondre_message' => 'Resp&ograve;ndre a aqueu messatge',
'resultats_recherche' => 'Resultats de la c&egrave;rca',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament dei forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat emb SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'suite' => 'seguda',
'sur_web' => 'Sobre lo web',
'syndiquer_rubrique' => 'Sindicar aquela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'V&egrave;tz la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Aquela letra recensa lu articles e br&egrave;vas publicats desp&iacute;',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Ve&egrave;tz en linha',
'voir_squelette' => 'telecargar l\'esqueleta d\'aquela p&agrave;gina'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_oc_ni_la.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acuelh dau sit',
'article' => 'Article', # NEW
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aquel autor',
'articles_populaires' => 'Lu articles mai populars',
'articles_rubrique' => 'Articles d\'aquela rubrica',
'aucun_article' => 'I a minga d\'article a aquela adrei&ccedil;a ',
'aucun_auteur' => 'I a minga d\'autor a aquela adrei&ccedil;a ',
'aucun_site' => 'I a minga de sit a aquela adrei&ccedil;a ',
'aucune_breve' => 'I a minga de br&egrave;va a aquela adrei&ccedil;a ',
'aucune_rubrique' => 'I a minga de rubrica a aquela adrei&ccedil;a ',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Autri br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
'autres_sites' => 'Autres sits',

// B
'bonjour' => 'B&ograve;njorn',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aqueu sit',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Data',
'dernier_ajout' => 'Darrier apondon',
'dernieres_breves' => 'Darrieri br&egrave;vas',
'derniers_articles' => 'Darriers articles',
'derniers_commentaires' => 'Darriers comentaris',
'derniers_messages_forum' => 'Darriers messatges publicats dins lu forums',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En resp&ograve;sta a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Dau meteis autor',
'meme_rubrique' => 'Dins la meteissa rubrica',
'memes_auteurs' => 'Dei meteis autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Lu messatges de forums mai recents',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Mots clau',
'mots_clefs_meme_groupe' => 'Mots clau dins lo meteis grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Li novetats',
'nouveautes_web' => 'Novetats sobre lo web',
'nouveaux_articles' => 'Articles n&ograve;us',
'nouvelles_breves' => 'Br&egrave;vas n&ograve;vi',

// P
'page_precedente' => 'p&agrave;gina precedenta',
'page_suivante' => 'p&agrave;gina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Pod&egrave;tz participar a la vida d\'aqueu sit e prepauar lu articles v&ograve;stres en v\'inscrivent &ccedil;ai sota. Recebretz sus lo c&ograve;up un e-mail que v\'indicar&agrave; lu v&ograve;stres c&ograve;des per accedir a l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Pod&egrave;tz prepauar un sit d\'apondre a aquesta rubrica:',

// R
'repondre_article' => 'Resp&ograve;ndre a aquel article',
'repondre_breve' => 'Resp&ograve;ndre a aquela br&egrave;va',
'repondre_message' => 'Resp&ograve;ndre a aqueu messatge',
'resultats_recherche' => 'Resultats de la c&egrave;rca',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament dei forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat emb SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'spam' => 'Spam', # NEW
'suite' => 'seguda',
'sur_web' => 'Sobre lo web',
'syndiquer_rubrique' => 'Sindicar aquela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'V&egrave;tz la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Aquela letra recensa lu articles e br&egrave;vas publicats desp&iacute;',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Ve&egrave;tz en linha',
'voir_squelette' => 'telecargar l\'esqueleta d\'aquela p&agrave;gina'
);

?>
